@@ -5,6 +5,14 @@ use warnings;
 
 use XSLoader;
 XSLoader::load 'YAML::LibYAML::XS';
+use base 'Exporter';
+
+our @EXPORT_OK = qw(Load Dump);
+
+sub Dump {
+    return '' unless @_;
+    return DumpXS(@_);
+}
 
 1;
 
